.. EspressoDB documentation master file, created by
   sphinx-quickstart on Thu Sep 19 10:14:11 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to EspressoDB's documentation!
======================================

Welcome to the documentation of `EspressoDB` -- an open source Python package for managing scientific data using Django_.

.. _Django: https://www.djangoproject.com

.. toctree::
   :caption: Contents:

   README
   Usage
   example/index
   faq
   features/index
   customizations/index
   api/index
   CONTRIBUTING
